==> eslint-config-availity-4.0.7.tgz: package/ts-recommended.js <==
module.exports = {
  '@typescript-eslint/adjacent-overload-signatures': 'error',
  '@typescript-eslint/array-type': 'error',
  '@typescript-eslint/ban-types': 'error',
  camelcase: 'off',
  '@typescript-eslint/camelcase': 'error',
  '@typescript-eslint/class-name-casing': 'error',
  '@typescript-eslint/explicit-function-return-type': 'warn',
  '@typescript-eslint/explicit-member-accessibility': 'error',
  indent: 'off',
  '@typescript-eslint/indent': 'error',
  '@typescript-eslint/interface-name-prefix': 'error',
  '@typescript-eslint/member-delimiter-style': 'error',
  '@typescript-eslint/no-angle-bracket-type-assertion': 'error',
  'no-array-constructor': 'off',
  '@typescript-eslint/no-array-constructor': 'error',
  '@typescript-eslint/no-empty-interface': 'error',
  '@typescript-eslint/no-explicit-any': 'warn',
  '@typescript-eslint/no-inferrable-types': 'error',
  '@typescript-eslint/no-misused-new': 'error',
  '@typescript-eslint/no-namespace': 'error',
  '@typescript-eslint/no-non-null-assertion': 'error',
  '@typescript-eslint/no-object-literal-type-assertion': 'error',
  '@typescript-eslint/no-parameter-properties': 'error',
  '@typescript-eslint/no-triple-slash-reference': 'error',
  'no-unused-vars': 'off',
  '@typescript-eslint/no-unused-vars': 'warn',
  'no-use-before-define': 'off',
  '@typescript-eslint/no-use-before-define': 'error',
  '@typescript-eslint/no-var-requires': 'error',
  '@typescript-eslint/prefer-interface': 'error',
  '@typescript-eslint/prefer-namespace-keyword': 'error',
  '@typescript-eslint/type-annotation-spacing': 'error',
};

==> eslint-config-availity-5.1.2.tgz: package/ts-recommended.js <==
module.exports = {
  '@typescript-eslint/adjacent-overload-signatures': 'error',
  '@typescript-eslint/array-type': 'error',
  '@typescript-eslint/ban-types': 'error',
  camelcase: 'off',
  '@typescript-eslint/camelcase': 'error',
  '@typescript-eslint/class-name-casing': 'error',
  '@typescript-eslint/explicit-function-return-type': ['warn',{
    "allowExpressions": true,
    "allowTypedFunctionExpressions": true
  }],
  '@typescript-eslint/explicit-member-accessibility': 'error',
  indent: 'off',
  '@typescript-eslint/indent': 'error',
  '@typescript-eslint/interface-name-prefix': 'error',
  '@typescript-eslint/member-delimiter-style': 'error',
  '@typescript-eslint/no-angle-bracket-type-assertion': 'error',
  'no-array-constructor': 'off',
  '@typescript-eslint/no-array-constructor': 'error',
  '@typescript-eslint/no-empty-interface': 'error',
  '@typescript-eslint/no-explicit-any': 'warn',
  '@typescript-eslint/no-inferrable-types': 'error',
  '@typescript-eslint/no-misused-new': 'error',
  '@typescript-eslint/no-namespace': 'error',
  '@typescript-eslint/no-non-null-assertion': 'error',
  '@typescript-eslint/no-object-literal-type-assertion': 'error',
  '@typescript-eslint/no-parameter-properties': 'error',
  '@typescript-eslint/no-triple-slash-reference': 'error',
  'no-unused-vars': 'off',
  '@typescript-eslint/no-unused-vars': 'warn',
  'no-use-before-define': 'off',
  '@typescript-eslint/no-use-before-define': 'error',
  '@typescript-eslint/no-var-requires': 'error',
  '@typescript-eslint/prefer-interface': 'error',
  '@typescript-eslint/prefer-namespace-keyword': 'error',
  '@typescript-eslint/type-annotation-spacing': 'error',
};
